@@ -89,9 +89,10 @@ static PyObject *do_create(const char *name, int ndims, npy_intp *dims, PyArray_
 	/* Append the meta-data to the array in memory */
 	meta = (struct array_meta *) (map_addr + (map_size - sizeof (*meta)));
 	strncpy(meta->magic, SHARED_ARRAY_MAGIC, sizeof (meta->magic));
-	meta->size = size;
-	meta->typenum = dtype->type_num;
-	meta->ndims = ndims;
+	meta->size     = size;
+	meta->typenum  = dtype->type_num;
+	meta->itemsize = dtype->elsize;
+	meta->ndims    = ndims;
 	for (i = 0; i < ndims; i++)
 		meta->dims[i] = dims[i];
 
@@ -103,7 +104,9 @@ static PyObject *do_create(const char *name, int ndims, npy_intp *dims, PyArray_
 	map_owner->name = strdup(name);
 
 	/* Create the array object */
-	array = PyArray_SimpleNewFromData(ndims, dims, dtype->type_num, map_addr);
+	array = PyArray_New(&PyArray_Type, meta->ndims, meta->dims,
+	                    meta->typenum, NULL, map_addr, meta->itemsize,
+	                    NPY_ARRAY_CARRAY, NULL);
 
 	/* Attach MapOwner to the array */
 	PyArray_SetBaseObject((PyArrayObject *) array, (PyObject *) map_owner);
