@@ -1,17 +1,17 @@
-/*
+/* 
  * This file is part of SharedArray.
  * Copyright (C) 2014-2017 Mathieu Mirmont <mat@parad0x.org>
- *
+ * 
  * SharedArray is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
- *
+ * 
  * SharedArray is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
  * along with SharedArray.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -50,7 +50,7 @@ static PyObject *do_delete(const char *name)
 	}
 
 	/* Ignore short files */
-	if (file_info.st_size < (off_t) sizeof (*meta)) {
+	if (file_info.st_size < sizeof (*meta)) {
 		close(fd);
 		PyErr_SetString(PyExc_IOError, "No SharedArray at this address");
 		return NULL;
